@@ -876,6 +876,8 @@ def list_users():
     search_client: SearchClient = CLIENT.account_client.get_users(user_search)
     users: List[User] = search_client.list_all()
 
+    users.sort(key=lambda user: user.name)
+
     if len(users) == 0:
         print_log("No Users to display")
         return
@@ -897,6 +899,7 @@ def list_applications():
         application_search
     )
     applications: List[Application] = search_client.list_all()
+    applications.sort(key=lambda app: app.name)
 
     if len(applications) == 0:
         print_log("No Applications to display")
@@ -922,6 +925,8 @@ def list_groups():
         print_log("No Groups to display")
         return
 
+    group_summaries.sort(key=lambda group: group.name if group.name is not None else "")
+
     groups: List[Group] = [
         CLIENT.account_client.get_group(x.id) for x in group_summaries
     ]
@@ -946,13 +951,16 @@ def list_roles():
         print_log("No Roles to display")
         return
 
-    groups: List[Role] = [CLIENT.account_client.get_role(x.id) for x in role_summaries]
+    role_summaries.sort(key=lambda role: role.name if role.name is not None else "")
+
+    print_log("Obtaining permissions for each role ...")
+    roles: List[Role] = [CLIENT.account_client.get_role(x.id) for x in role_summaries]
 
     if not ARGS_PARSER.details:
-        print_numbered_object_list(CLIENT, groups, object_type_name="Role")
+        print_numbered_object_list(CLIENT, roles, object_type_name="Role")
         return
 
-    for selected_users in select(CLIENT, groups, object_type_name="Role"):
+    for selected_users in select(CLIENT, roles, object_type_name="Role"):
         print_yd_object(selected_users)
 
 
