@@ -196,6 +196,13 @@ class CLIParser:
                 help="the tag to search when listing entities",
                 metavar="<tag>",
             )
+            parser.add_argument(
+                "--ids-only",
+                "-D",
+                action="store_true",
+                required=False,
+                help="list the YellowDog IDs only",
+            )
 
         if any(module in sys.argv[0] for module in ["submit"]):
             parser.add_argument(
@@ -336,7 +343,7 @@ class CLIParser:
                 "-a",
                 action="store_true",
                 required=False,
-                help="abort all running tasks with immediate effect",
+                help="abort running tasks with immediate effect",
             )
             parser.add_argument(
                 "--follow",
@@ -620,6 +627,30 @@ class CLIParser:
                 required=False,
                 help="list namespace policies",
             )
+            parser.add_argument(
+                "--users",
+                action="store_true",
+                required=False,
+                help="list users",
+            )
+            parser.add_argument(
+                "--applications",
+                action="store_true",
+                required=False,
+                help="list applications",
+            )
+            parser.add_argument(
+                "--groups",
+                action="store_true",
+                required=False,
+                help="list groups",
+            )
+            parser.add_argument(
+                "--roles",
+                action="store_true",
+                required=False,
+                help="list roles",
+            )
             parser.add_argument(
                 "--output-file",
                 type=str,
@@ -775,6 +806,13 @@ class CLIParser:
                 required=False,
                 help="follow worker pool shutdown to completion",
             )
+            parser.add_argument(
+                "--terminate",
+                "-T",
+                action="store_true",
+                required=False,
+                help="also immediately terminate associated compute requirement(s)",
+            )
 
         if "terminate" in sys.argv[0]:
             parser.add_argument(
@@ -802,7 +840,7 @@ class CLIParser:
                 type=str,
                 help=(
                     "the name(s) or YellowDog ID(s) of the work requirement(s) to be"
-                    " cancelled"
+                    " cancelled; can also supply task IDs"
                 ),
             )
 
@@ -1487,6 +1525,26 @@ class CLIParser:
     def namespace_policies(self) -> Optional[bool]:
         return self.args.namespace_policies
 
+    @property
+    @allow_missing_attribute
+    def users(self) -> Optional[bool]:
+        return self.args.users
+
+    @property
+    @allow_missing_attribute
+    def applications(self) -> Optional[bool]:
+        return self.args.applications
+
+    @property
+    @allow_missing_attribute
+    def groups(self) -> Optional[bool]:
+        return self.args.groups
+
+    @property
+    @allow_missing_attribute
+    def roles(self) -> Optional[bool]:
+        return self.args.roles
+
     @property
     @allow_missing_attribute
     def show_keyring_passwords(self) -> Optional[bool]:
@@ -1632,6 +1690,16 @@ class CLIParser:
     def worker_pool_ids(self) -> Optional[List[str]]:
         return self.args.worker_pool_ids
 
+    @property
+    @allow_missing_attribute
+    def ids_only(self) -> Optional[bool]:
+        return self.args.ids_only
+
+    @property
+    @allow_missing_attribute
+    def terminate(self) -> Optional[bool]:
+        return self.args.terminate
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
