@@ -68,6 +68,7 @@ from yellowdog_cli.utils.settings import (
     HIGHLIGHTED_STATES,
     JSON_INDENT,
     MAX_LINES_COLOURED_FORMATTING,
+    MAX_TABLE_DESCRIPTION,
     NAMESPACE_OBJECT_STORE_PREFIX_SEPARATOR,
     PROP_RESOURCE,
     WARNING_STYLE,
@@ -401,6 +402,7 @@ def compute_requirement_template_table(
         "Name",
         "Namespace",
         "Type",
+        "Description",
         "Strategy Type",
         "Compute Requirement Template ID",
     ]
@@ -422,6 +424,7 @@ def compute_requirement_template_table(
                 crt_summary.name,
                 crt_summary.namespace,
                 type,
+                _truncate_text(crt_summary.description),
                 strategy_type,
                 crt_summary.id,
             ]
@@ -436,6 +439,7 @@ def compute_source_template_table(
         "#",
         "Name",
         "Namespace",
+        "Description",
         "Provider",
         "Type",
         "Compute Source Template ID",
@@ -455,6 +459,7 @@ def compute_source_template_table(
                 index + 1,
                 cst_summary.name,
                 cst_summary.namespace,
+                _truncate_text(cst_summary.description),
                 provider,
                 type,
                 cst_summary.id,
@@ -478,7 +483,7 @@ def keyring_table(
             [
                 index + 1,
                 keyring.name,
-                keyring.description,
+                _truncate_text(keyring.description),
                 keyring.id,
             ]
         )
@@ -634,7 +639,7 @@ def allowances_table(
             [
                 index + 1,
                 allowance.type.split(".")[-1],
-                allowance.description,
+                _truncate_text(allowance.description),
                 allowance.allowedHours,
                 allowance.remainingHours,
                 allowance.limitEnforcement,
@@ -667,7 +672,7 @@ def attribute_definitions_table(
                 attribute_definition["name"],
                 attribute_definition["type"].split(".")[-1],
                 attribute_definition["title"],
-                attribute_definition.get("description", ""),
+                _truncate_text(attribute_definition.get("description", "")),
             ]
         )
     return headers, table
@@ -768,7 +773,7 @@ def applications_table(
             [
                 index + 1,
                 application.name,
-                application.description,
+                _truncate_text(application.description),
                 application.id,
             ]
         )
@@ -793,7 +798,7 @@ def groups_table(
                 index + 1,
                 group.name,
                 group.adminGroup,
-                f"{group.description[:40] + '...' if len(group.description) > 40 else group.description}",
+                _truncate_text(group.description),
                 ", ".join([x.role.name for x in group.roles]),
                 group.id,
             ]
@@ -817,7 +822,7 @@ def roles_table(
             [
                 index + 1,
                 role.name,
-                f"{permissions[:40] + '...' if len(permissions) > 40 else permissions}",
+                _truncate_text(permissions),
                 role.id,
             ]
         )
@@ -1445,3 +1450,13 @@ def _print_to_file(json_string: str, output_file: str, with_final_comma: bool =
         raise Exception(f"Cannot open output file for writing: {e}")
 
     FIRST_OUTPUT_TO_FILE = False
+
+
+def _truncate_text(description: Union[str, None]):
+    """
+    Truncate a description to fit within MAX_TABLE_DESCRIPTION.
+    """
+    if description is None:
+        return ""
+
+    return f"{description[:MAX_TABLE_DESCRIPTION - 3] + '...' if len(description) > MAX_TABLE_DESCRIPTION else description}"
